@@ -13,7 +13,7 @@ from PySide.QtNetwork import QNetworkAccessManager, QNetworkCookieJar, \
                              QNetworkReply, QNetworkRequest
 from LTdatabase       import LTDatabase
 
-version = '0.0.1'
+version = '0.0.2'
 exportUrl = QUrl('http://www.librarything.com/export-tab')
 loginUrl  = QUrl('http://www.librarything.com/signup.php')
 
@@ -39,12 +39,11 @@ class LTColumnSelectGeneric(QDialog): #{{{1
         self._availableColumns.connect(SIGNAL('doubleClicked(QModelIndex)'), self.moveItemClick)
         self._availableColumns.model().sort(0)
 
-        box = QGroupBox('Available fields')
         lyt = QVBoxLayout()
+        lyt.addWidget(QLabel('<b>Available fields</b>'))
         lyt.addWidget(self._availableColumns)
-        box.setLayout(lyt)
 
-        return box
+        return lyt
 
     def setupSelectedList(self, model, name): #{{{2
         self._selectedColumns = QListView()
@@ -54,14 +53,13 @@ class LTColumnSelectGeneric(QDialog): #{{{1
         self._selectedColumns.connect(SIGNAL('doubleClicked(QModelIndex)'), self.moveItemClick)
         self._selectedColumns.model() # This is needed to force the display
 
-        box = QGroupBox(name)
         lyt = QVBoxLayout()
+        lyt.addWidget(QLabel('<b>' + name + '</b>'))
         lyt.addWidget(self._selectedColumns)
-        box.setLayout(lyt)
 
-        return box
+        return lyt
 
-    def setupDialog(self, availBox, selBox): #{{{2
+    def setupDialog(self, availLyt, selLyt): #{{{2
         # Set up the up/down arrows for ordering the display columns {{{3
         orderBtnUp = QToolButton()
         orderBtnUp.setArrowType(Qt.UpArrow)
@@ -94,15 +92,13 @@ class LTColumnSelectGeneric(QDialog): #{{{1
         exitButtons.connect(SIGNAL('rejected()'), self.reject)
 
         # Add all the widgets to the window {{{3
-        lyt1 = QHBoxLayout()
-        lyt2 = QVBoxLayout()
-        lyt1.addWidget(availBox)
-        lyt1.addLayout(selectBtnBox)
-        lyt1.addWidget(selBox)
-        lyt1.addLayout(orderBtnBox)
-        lyt2.addLayout(lyt1)
-        lyt2.addWidget(exitButtons)
-        self.setLayout(lyt2)
+        selLyt.addWidget(exitButtons)
+        lyt = QHBoxLayout()
+        lyt.addLayout(availLyt)
+        lyt.addLayout(selectBtnBox)
+        lyt.addLayout(selLyt)
+        lyt.addLayout(orderBtnBox)
+        self.setLayout(lyt)
 
     def moveItemLeft(self): #{{{2
         item = self._selectedColumns.currentIndex()
@@ -287,11 +283,24 @@ class LTMainWindow(QWidget): #{{{1
         self.setMinimumSize(800, 480)
         self.setWindowTitle('LibraryThing Viewer')
 
+        QHBoxLayout(self)
+
+    def setupMenu(self): #{{{2
+        menu = QMenuBar()
+
+        # Set up the menu
+        menu.addAction('Display Fields').connect(SIGNAL('triggered()'), self.displayFields)
+        menu.addAction('Sort Order').connect(SIGNAL('triggered()'), self.sortOrder)
+        menu.addAction('Load Export File').connect(SIGNAL('triggered()'), self.loadFile)
+        menu.addAction('Download Export File').connect(SIGNAL('triggered()'), self.downloadExportFile)
+        menu.addAction('About').connect(SIGNAL('triggered()'), self.about)
+
+        self.layout().setMenuBar(menu)
+        self._menu = menu
+
     def setupScreen(self): #{{{2
         # Create the required objects
         self._tab      = QTableView()
-        self._box      = QHBoxLayout()
-        self._menu     = QMenuBar()
         self._model    = QSqlQueryModel()
         self._network  = QNetworkAccessManager(self)
         self._progress = QProgressDialog(self)
@@ -309,19 +318,6 @@ class LTMainWindow(QWidget): #{{{1
         # Instead connect the signal to each request
 #        self._network.connect(SIGNAL('finished(QNetworkReply)'), self.replyFinished)
 
-        # Set up the menu
-        m_fields = self._menu.addAction('Display Fields')
-        m_order  = self._menu.addAction('Sort Order')
-        m_load   = self._menu.addAction('Load Export File')
-        m_dl     = self._menu.addAction('Download Export File')
-        m_about  = self._menu.addAction('About')
-
-        m_fields.connect(SIGNAL('triggered()'), self.displayFields)
-        m_order.connect(SIGNAL('triggered()'), self.sortOrder)
-        m_load.connect(SIGNAL('triggered()'), self.loadFile)
-        m_dl.connect(SIGNAL('triggered()'), self.downloadExportFile)
-        m_about.connect(SIGNAL('triggered()'), self.about)
-
         # Set up the view pane
         self._tab.setCornerButtonEnabled(False)
         self._tab.setSelectionMode(QAbstractItemView.NoSelection)
@@ -338,9 +334,7 @@ class LTMainWindow(QWidget): #{{{1
         self._tab.connect(SIGNAL('doubleClicked(QModelIndex)'), self.viewBookInfo)
                     
         # Set up the main view
-        self._box.setMenuBar(self._menu)
-        self._box.addWidget(self._tab)
-        self.setLayout(self._box)
+        self.layout().addWidget(self._tab)
 
     def loadData(self): #{{{2
         # Set the SQL query to use
